#[repr(C)]pub struct LauncherSetOptionsRequest {
pub options: Uint32,
}Expand description
The wire type corresponding to LauncherSetOptionsRequest.
Fields
options: Uint32Trait Implementations
Sourceimpl Clone for LauncherSetOptionsRequest
impl Clone for LauncherSetOptionsRequest
Sourcefn clone(&self) -> LauncherSetOptionsRequest
fn clone(&self) -> LauncherSetOptionsRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for LauncherSetOptionsRequest
impl Constrained for LauncherSetOptionsRequest
Sourceimpl Debug for LauncherSetOptionsRequest
impl Debug for LauncherSetOptionsRequest
Sourceimpl<___D> Decode<___D> for LauncherSetOptionsRequestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for LauncherSetOptionsRequestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<LauncherSetOptionsRequest, ___E> for &'a LauncherSetOptionsRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<LauncherSetOptionsRequest, ___E> for &'a LauncherSetOptionsRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<LauncherSetOptionsRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<LauncherSetOptionsRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<LauncherSetOptionsRequest, ___E> for LauncherSetOptionsRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<LauncherSetOptionsRequest, ___E> for LauncherSetOptionsRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, LauncherSetOptionsRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, LauncherSetOptionsRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<LauncherSetOptionsRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<LauncherSetOptionsRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<LauncherSetOptionsRequest, ___E> for LauncherSetOptionsRequest<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
impl<___E, T0> Encode<LauncherSetOptionsRequest, ___E> for LauncherSetOptionsRequest<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<LauncherSetOptionsRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<LauncherSetOptionsRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<LauncherSetOptionsRequest> for LauncherSetOptionsRequest
impl FromWire<LauncherSetOptionsRequest> for LauncherSetOptionsRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<LauncherSetOptionsRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<LauncherSetOptionsRequest, Self>
Sourcefn from_wire(wire: LauncherSetOptionsRequest) -> Self
fn from_wire(wire: LauncherSetOptionsRequest) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<LauncherSetOptionsRequest> for LauncherSetOptionsRequest
impl FromWireRef<LauncherSetOptionsRequest> for LauncherSetOptionsRequest
Sourcefn from_wire_ref(wire: &LauncherSetOptionsRequest) -> Self
fn from_wire_ref(wire: &LauncherSetOptionsRequest) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for LauncherSetOptionsRequest
impl IntoNatural for LauncherSetOptionsRequest
Sourcetype Natural = LauncherSetOptionsRequest
type Natural = LauncherSetOptionsRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for LauncherSetOptionsRequest
impl Wire for LauncherSetOptionsRequest
Sourcetype Narrowed<'de> = LauncherSetOptionsRequest
type Narrowed<'de> = LauncherSetOptionsRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.